// VT_Mon.v
`timescale 1 ns/100 ps

module VT_Mon(CLK40M, SYS_RESET, INIT_POWER_UP, VAREF, Supply_good, Over_temp, ATRETURN01, AV5V, Temp);

input   CLK40M, SYS_RESET, INIT_POWER_UP, ATRETURN01;
input   AV5V, Temp;
output  Supply_good, Over_temp;
inout   VAREF;

// internal signals

wire INIT_DONE_net;
wire INIT_DONEn_net;
wire PLL_CLK40M;
wire SYS_RESET_net;
wire VAREF_net;
wire AV5V_net;
wire Temp_net;
wire Supply_good_net;
wire Supply_good_en_net;
wire Over_temp_en_net;
wire Over_temp_net;
wire ATRETURN01_net;
wire AV5V_over5p25_net;
wire AV5V_under4p75_net;
wire Temp_over70C_net;
wire [8:0] INIT_ADDR_net;
wire [8:0] INIT_DATA_net;
wire INIT_ACM_WEN_net;
wire INIT_ASSC_WEN_net;
wire INIT_EV_WEN_net;
wire INIT_TR_WEN_net;
wire INIT_POWER_UP_net;
wire CLK10M;

// connections to top level ports
assign SYS_RESET_net = SYS_RESET;
assign VAREF_net = VAREF;
assign AV5V_net = AV5V;
assign Temp_net = Temp;
assign ATRETURN01_net = ATRETURN01;
assign Supply_good = Supply_good_net;
assign Over_temp = Over_temp_net;
assign INIT_POWER_UP_net = INIT_POWER_UP;
assign INIT_DONEn_net = ! INIT_DONE_net;

// divide 40 MHz input clock by 4 to generate 10 MHz init clock
PLL_40_10 PLL_inst (.POWERDOWN(1'b1), .CLKA(CLK40M), .LOCK( ), .GLA(PLL_CLK40M), .GLC(CLK10M), .OADIVRST(1'b1));


// multiplex CLK10M and SYS_CLK for initialization
NGM NGMUX_inst(.CLK0(PLL_CLK40M), .CLK1(CLK10M), .S(INIT_DONEn_net), .GL(SYS_CLK_int));

// generate enable signals for gate drivers
assign  Over_temp_en_net = Temp_over70C_net;   // use over temp flag to turn on gate driver

assign Supply_good_en_net = !AV5V_under4p75_net & !AV5V_over5p25_net;

// instantiate Analog block
Analog Analog_inst (.SYS_CLK(SYS_CLK_int), 
                    .SYS_RESET(SYS_RESET_net), 
                    .VAREF(VAREF_net),
                    .DATAVALID( ), 
                    .AV5V(AV5V_net),
                    .Temp(Temp_net), 
                    .Supply_good(Supply_good_net),
                    .Supply_good_en(Supply_good_en_net),
                    .Over_temp(Over_temp_net),
                    .Over_temp_en(Over_temp_en_net), 
                    .ATRETURN01(ATRETURN01_net),
                    .AV5V_over5p25(AV5V_over5p25_net),
                    .AV5V_under4p75(AV5V_under4p75_net),
                    .Temp_over70C(Temp_over70C_net), 
                    .ASSC_DONE( ),
                    .ASSC_WAIT( ),
                    .ASSC_CHSAT( ),
                    .ASSC_CHLATD( ),
                    .INIT_ADDR(INIT_ADDR_net), 
                    .INIT_DATA(INIT_DATA_net),
                    .INIT_ACM_WEN(INIT_ACM_WEN_net),
                    .INIT_ASSC_WEN(INIT_ASSC_WEN_net),
                    .INIT_EV_WEN(INIT_EV_WEN_net), 
                    .INIT_TR_WEN(INIT_TR_WEN_net),
                    .INIT_DONE(INIT_DONE_net),
                    .ACMCLK(CLK10M),
                    .ACMRDATA_I());


// instantiate Flash Memory block
NVM_sys NVM_inst(.INIT_CLK(SYS_CLK_int),
                 .SYS_RESET(SYS_RESET_net),
                 .INIT_POWER_UP(INIT_POWER_UP_net),
                 .INIT_DONE(INIT_DONE_net), 
                 .INIT_DATA(INIT_DATA_net), 
                 .INIT_ADDR(INIT_ADDR_net),
                 .INIT_ACM_WEN(INIT_ACM_WEN_net),
                 .INIT_ASSC_WEN(INIT_ASSC_WEN_net),
                 .INIT_EV_WEN(INIT_EV_WEN_net), 
                 .INIT_TR_WEN(INIT_TR_WEN_net));

endmodule